==> kdevelop-4.7.1.tar.xz: kdevelop-4.7.1/languages/plugins/custom-definesandincludes/kdevdefinesandincludesmanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Custom Defines And Includes Manager
Name[ca]=Gestor per personalitzar les definicions i inclusions
Name[de]=Verwaltung eigener Definitionen und Includes
Name[en_GB]=Custom Defines And Includes Manager
Name[es]=Gestor de definiciones e inclusiones personalizadas
Name[et]=Kohandatud definitsioonide ja päiste haldur
Name[fi]=Mukautettujen definejen ja includejen hallinta
Name[fr]=Gestionnaire de définitions et inclusions personnalisées
Name[it]=Gestore delle definizioni e inclusioni personalizzate
Name[nl]=Beheerder van zelf gedefinieerd en invoegingen
Name[pl]=Zarządzanie własnymi definicjami i plikami dołączanymi
Name[pt]=Gestor de Definições e Inclusões Personalizadas
Name[pt_BR]=Gerenciador de definições e inclusões personalizadas
Name[sk]=Správca vlastných definícií a zahrnutí
Name[sl]=Upravljalnik določitev in vključitev po meri
Name[sv]=Hantering av egna definitioner och inkluderingar
Name[tr]=Özel Tanımlama ve İçerme Yöneticisi
Name[uk]=Керування нетиповими визначеннями і включеннями
Name[x-test]=xxCustom Defines And Includes Managerxx
GenericName=Custom Defines And Includes Manager
GenericName[ca]=Gestor per personalitzar les definicions i inclusions
GenericName[de]=Verwaltung eigener Definitionen und Includes
GenericName[en_GB]=Custom Defines And Includes Manager
GenericName[es]=Gestor de definiciones e inclusiones personalizadas
GenericName[et]=Kohandatud definitsioonide ja päiste haldur
GenericName[fi]=Mukautettujen definejen ja includejen hallinta
GenericName[fr]=Gestionnaire de définitions et inclusions personnalisées
GenericName[it]=Gestore delle definizioni e inclusioni personalizzate
GenericName[nl]=Beheerder van zelf gedefinieerd en invoegingen
GenericName[pl]=Zarządzanie własnymi definicjami i plikami dołączanymi
GenericName[pt]=Gestor de Definições e Inclusões Personalizadas
GenericName[pt_BR]=Gerenciador de definições e inclusões personalizadas
GenericName[sk]=Správca vlastných definícií a zahrnutí
GenericName[sl]=Upravljalnik določitev in vključitev po meri
GenericName[sv]=Hantering av egna definitioner och inkluderingar
GenericName[tr]=Özel Tanımlama ve İçerme Yöneticisi
GenericName[uk]=Керування нетиповими визначеннями і включеннями
GenericName[x-test]=xxCustom Defines And Includes Managerxx
Comment=Configure which macros and include directories/files will be added to the parser during project parsing.
Comment[ca]=Configura quines macros i directoris/fitxers s'afegiran a l'analitzador durant l'anàlisi del projecte.
Comment[de]=Einstellung der Makros und Include-Ordner/-Dateien, die zum für den Parser während des Einlesens des Projekts hinzugefügt werden.
Comment[en_GB]=Configure which macros and include directories/files will be added to the parser during project parsing.
Comment[es]=Configurar las macros y los directorios/archivos a incluir que se añadirán al analizador sintáctico durante el análisis de los proyectos.
Comment[et]=Aitab seadistada, millised makrod ja päistekataloogid või -failid lisada parserile projekti parsimiseks.
Comment[fi]=Määritä, mitkä makrot ja include-hakemistot/tiedostot lisätään jäsentimelle projektin jäsentämisen aikana.
Comment[fr]=Configurer quelles macros et dossiers ou fichiers d'inclusions seront ajoutés à l'analyseur pendant l'analyse du projet.
Comment[it]=Configura quali macro e cartelle/file di inclusione saranno aggiunti all'analizzatore durante l'analisi del progetto.
Comment[nl]=Stel in welke macro's en ingevoegde mappen/bestanden toegevoegd zullen worden aan de parser bij het ontleden van het project.
Comment[pl]=Ustaw jakie pliki/katalogi makr i plików dołączanych będą dodawane do przetwarzania przy przetwarzaniu projektu.
Comment[pt]=Configure quais as macros e pastas/ficheiros de inclusão que serão adicionados ao processador do projecto.
Comment[pt_BR]=Configura quais macros e arquivos/pastas incluídos serão adicionados ao processador durante o processamento do projeto.
Comment[sk]=Nastaviť, ktoré makrá a zahrnuté adresáre/súbory sa pridajú do spracovača počas spracovania projektu.
Comment[sl]=Nastavite, kateri makri in mape oz. datoteke z vključitvami bodo dodane razčlenjevalniku med razčlenjevanjem projekta.
Comment[sv]=Anpassa vilka makron och filer eller kataloger att inkludera som läggs till i tolken under projekttolkning
Comment[tr]=Proje ayrıştırılırken hangi makroların ve içerme dizinlerinin/dosyaların ayrıştırıcıya ekleneceğini yapılandırın.
Comment[uk]=Налаштувати макроси і включені каталоги або файли, які буде додано під час обробки проекту.
Comment[x-test]=xxConfigure which macros and include directories/files will be added to the parser during project parsing.xx
Icon=kdevelop
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevdefinesandincludesmanager
X-KDE-PluginInfo-Name=KDevDefinesAndIncludesManager
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.IDefinesAndIncludesManager
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn

==> kdevelop-4.7.2.tar.xz: kdevelop-4.7.2/languages/plugins/custom-definesandincludes/kdevdefinesandincludesmanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Custom Defines And Includes Manager
Name[bs]=Menadžer vlastitih definicija i uključivanja
Name[ca]=Gestor per personalitzar les definicions i inclusions
Name[de]=Verwaltung eigener Definitionen und Includes
Name[en_GB]=Custom Defines And Includes Manager
Name[es]=Gestor de definiciones e inclusiones personalizadas
Name[et]=Kohandatud definitsioonide ja päiste haldur
Name[fi]=Mukautettujen definejen ja includejen hallinta
Name[fr]=Gestionnaire de définitions et inclusions personnalisées
Name[it]=Gestore delle definizioni e inclusioni personalizzate
Name[nl]=Beheerder van zelf gedefinieerd en invoegingen
Name[pl]=Zarządzanie własnymi definicjami i plikami dołączanymi
Name[pt]=Gestor de Definições e Inclusões Personalizadas
Name[pt_BR]=Gerenciador de definições e inclusões personalizadas
Name[sk]=Správca vlastných definícií a zahrnutí
Name[sl]=Upravljalnik določitev in vključitev po meri
Name[sv]=Hantering av egna definitioner och inkluderingar
Name[tr]=Özel Tanımlama ve İçerme Yöneticisi
Name[uk]=Керування нетиповими визначеннями і включеннями
Name[x-test]=xxCustom Defines And Includes Managerxx
GenericName=Custom Defines And Includes Manager
GenericName[bs]=Menadžer vlastitih definicija i uključivanja
GenericName[ca]=Gestor per personalitzar les definicions i inclusions
GenericName[de]=Verwaltung eigener Definitionen und Includes
GenericName[en_GB]=Custom Defines And Includes Manager
GenericName[es]=Gestor de definiciones e inclusiones personalizadas
GenericName[et]=Kohandatud definitsioonide ja päiste haldur
GenericName[fi]=Mukautettujen definejen ja includejen hallinta
GenericName[fr]=Gestionnaire de définitions et inclusions personnalisées
GenericName[it]=Gestore delle definizioni e inclusioni personalizzate
GenericName[nl]=Beheerder van zelf gedefinieerd en invoegingen
GenericName[pl]=Zarządzanie własnymi definicjami i plikami dołączanymi
GenericName[pt]=Gestor de Definições e Inclusões Personalizadas
GenericName[pt_BR]=Gerenciador de definições e inclusões personalizadas
GenericName[sk]=Správca vlastných definícií a zahrnutí
GenericName[sl]=Upravljalnik določitev in vključitev po meri
GenericName[sv]=Hantering av egna definitioner och inkluderingar
GenericName[tr]=Özel Tanımlama ve İçerme Yöneticisi
GenericName[uk]=Керування нетиповими визначеннями і включеннями
GenericName[x-test]=xxCustom Defines And Includes Managerxx
Comment=Configure which macros and include directories/files will be added to the parser during project parsing.
Comment[bs]=Konfiguriše koji makroi i direktoriji/uključivanja će se dodati parseru tokom parsiranja projekta.
Comment[ca]=Configura quines macros i directoris/fitxers s'afegiran a l'analitzador durant l'anàlisi del projecte.
Comment[de]=Einstellung der Makros und Include-Ordner/-Dateien, die zum für den Parser während des Einlesens des Projekts hinzugefügt werden.
Comment[en_GB]=Configure which macros and include directories/files will be added to the parser during project parsing.
Comment[es]=Configurar las macros y los directorios/archivos a incluir que se añadirán al analizador sintáctico durante el análisis de los proyectos.
Comment[et]=Aitab seadistada, millised makrod ja päistekataloogid või -failid lisada parserile projekti parsimiseks.
Comment[fi]=Määritä, mitkä makrot ja include-hakemistot/tiedostot lisätään jäsentimelle projektin jäsentämisen aikana.
Comment[fr]=Configurer quelles macros et dossiers ou fichiers d'inclusions seront ajoutés à l'analyseur pendant l'analyse du projet.
Comment[it]=Configura quali macro e cartelle/file di inclusione saranno aggiunti all'analizzatore durante l'analisi del progetto.
Comment[nl]=Stel in welke macro's en ingevoegde mappen/bestanden toegevoegd zullen worden aan de parser bij het ontleden van het project.
Comment[pl]=Ustaw jakie pliki/katalogi makr i plików dołączanych będą dodawane do przetwarzania przy przetwarzaniu projektu.
Comment[pt]=Configure quais as macros e pastas/ficheiros de inclusão que serão adicionados ao processador do projecto.
Comment[pt_BR]=Configura quais macros e arquivos/pastas incluídos serão adicionados ao processador durante o processamento do projeto.
Comment[sk]=Nastaviť, ktoré makrá a zahrnuté adresáre/súbory sa pridajú do spracovača počas spracovania projektu.
Comment[sl]=Nastavite, kateri makri in mape oz. datoteke z vključitvami bodo dodane razčlenjevalniku med razčlenjevanjem projekta.
Comment[sv]=Anpassa vilka makron och filer eller kataloger att inkludera som läggs till i tolken under projekttolkning
Comment[tr]=Proje ayrıştırılırken hangi makroların ve içerme dizinlerinin/dosyaların ayrıştırıcıya ekleneceğini yapılandırın.
Comment[uk]=Налаштувати макроси і включені каталоги або файли, які буде додано під час обробки проекту.
Comment[x-test]=xxConfigure which macros and include directories/files will be added to the parser during project parsing.xx
Comment[zh_CN]=配置在解析项目时加入哪些宏、引用目录和文件。
Icon=kdevelop
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevdefinesandincludesmanager
X-KDE-PluginInfo-Name=KDevDefinesAndIncludesManager
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.IDefinesAndIncludesManager
X-KDevelop-Mode=NoGUI
X-KDevelop-LoadMode=AlwaysOn
